@@ -7,28 +7,16 @@
  *          Krzesimir Nowak <krnowak@openismus.com>
  *          Christophe Guiraud <christophe.guiraud@intel.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
- * SECTION:gupnp-didl-lite-container
- * @short_description: DIDL-Lite Container
+ * GUPnPDIDLLiteContainer:
  *
- * #GUPnPDIDLLiteContainer respresents a DIDL-Lite container element.
+ * Representation of a DIDL-Lite container element.
  */
+#include <config.h>
 
 #include <string.h>
 
@@ -41,7 +29,7 @@
 
 G_DEFINE_TYPE (GUPnPDIDLLiteContainer,
                gupnp_didl_lite_container,
-               GUPNP_TYPE_DIDL_LITE_OBJECT);
+               GUPNP_TYPE_DIDL_LITE_OBJECT)
 
 enum {
         PROP_0,
@@ -156,7 +144,7 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
         object_class->set_property = gupnp_didl_lite_container_set_property;
 
         /**
-         * GUPnPDIDLLiteContainer:searchable:
+         * GUPnPDIDLLiteContainer:searchable:(attributes org.gtk.Property.get=gupnp_didl_lite_container_get_searchable org.gtk.Property.set=gupnp_didl_lite_container_set_searchable):
          *
          * Whether this container is searchable.
          **/
@@ -173,7 +161,7 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
                                        G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPDIDLLiteContainer:child-count:
+         * GUPnPDIDLLiteContainer:child-count:(attributes org.gtk.Property.get=gupnp_didl_lite_container_get_child_count org.gtk.Property.set=gupnp_didl_lite_container_set_child_count):
          *
          * The child count of this container.
          **/
@@ -192,7 +180,7 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
                                    G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPDIDLLiteContainer:storage-used:
+         * GUPnPDIDLLiteContainer:storage-used:(attributes org.gtk.Property.get=gupnp_didl_lite_container_get_storage_used org.gtk.Property.set=gupnp_didl_lite_container_set_storage_used):
          *
          * The number of bytes used by all child items of this container.
          **/
@@ -212,7 +200,7 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
                                      G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPDIDLLiteContainer:container-update-id:
+         * GUPnPDIDLLiteContainer:container-update-id:(attributes org.gtk.Property.get=gupnp_didl_lite_container_get_container_update_id org.gtk.Property.set=gupnp_didl_lite_container_set_container_update_id):
          *
          * Update ID of this container.
          **/
@@ -231,7 +219,7 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
                                                  G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPDIDLLiteContainer:total-deleted-child-count:
+         * GUPnPDIDLLiteContainer:total-deleted-child-count:(attributes org.gtk.Property.get=gupnp_didl_lite_container_get_total_deleted_child_count org.gtk.Property.set=gupnp_didl_lite_container_set_total_deleted_child_count):
          *
          * Total deleted child count of this container.
          **/
@@ -251,7 +239,7 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
 }
 
 /**
- * gupnp_didl_lite_container_get_searchable:
+ * gupnp_didl_lite_container_get_searchable:(attributes org.gtk.Method.get_property=searchable):
  * @container: #GUPnPDIDLLiteContainer
  *
  * Checks whether @container is searchable.
@@ -273,11 +261,12 @@ gupnp_didl_lite_container_get_searchable (GUPnPDIDLLiteContainer *container)
 }
 
 /**
- * gupnp_didl_lite_container_get_child_count:
+ * gupnp_didl_lite_container_get_child_count:(attributes org.gtk.Method.get_property=child-count):
  * @container: #GUPnPDIDLLiteContainer
  *
- * Get the child count of the @container.  If the child count is unknown, -1 is
- * returned.
+ * Get the child count of the @container.
+ *
+ * If the child count is unknown, -1 is returned.
  *
  * Return value: The child count of the @container, or -1 if it is unknown.
  **/
@@ -296,7 +285,7 @@ gupnp_didl_lite_container_get_child_count (GUPnPDIDLLiteContainer *container)
 }
 
 /**
- * gupnp_didl_lite_container_get_container_update_id:
+ * gupnp_didl_lite_container_get_container_update_id:(attributes org.gtk.Method.get_property=container-update-id):
  * @container: #GUPnPDIDLLiteContainer
  *
  * Get the container update ID of the @container.
@@ -346,7 +335,7 @@ gupnp_didl_lite_container_container_update_id_is_set
 }
 
 /**
- * gupnp_didl_lite_container_get_total_deleted_child_count:
+ * gupnp_didl_lite_container_get_total_deleted_child_count:(attributes org.gtk.Method.get_property=total-deleted-child-count):
  * @container: #GUPnPDIDLLiteContainer
  *
  * Get the total deleted child count of the @container.
@@ -374,7 +363,7 @@ gupnp_didl_lite_container_get_total_deleted_child_count
  * gupnp_didl_lite_container_total_deleted_child_count_is_set:
  * @container: #GUPnPDIDLLiteContainer
  *
- * Get whether the total deleted child conut of the @container is set.
+ * Get whether the total deleted child count of the @container is set.
  *
  * Return value: %TRUE if property is set, otherwise %FALSE
  **/
@@ -402,7 +391,6 @@ gupnp_didl_lite_container_total_deleted_child_count_is_set
  *
  * Returns: (element-type utf8) (transfer full): The list of create classes
  * belonging to @container, or %NULL.
- * #g_list_free the returned list after usage and #g_free each string in it.
  **/
 GList *
 gupnp_didl_lite_container_get_create_classes (GUPnPDIDLLiteContainer *container)
@@ -442,9 +430,8 @@ gupnp_didl_lite_container_get_create_classes (GUPnPDIDLLiteContainer *container)
  *
  * Gets the list of create classes of the @container.
  *
- * Returns: (element-type GUPnPDIDLLiteCreateClass*) (transfer full): The list
+ * Returns: (element-type GUPnPDIDLLiteCreateClass) (transfer full): The list
  * of create classes belonging to @container, or %NULL.
- * #g_list_free the returned list after usage and unref each object in it.
  **/
 GList *
 gupnp_didl_lite_container_get_create_classes_full (
@@ -525,10 +512,11 @@ gupnp_didl_lite_container_get_search_classes (GUPnPDIDLLiteContainer *container)
 }
 
 /**
- * gupnp_didl_lite_container_get_storage_used:
+ * gupnp_didl_lite_container_get_storage_used:(attributes org.gtk.Method.get_property=storage-used):
  * @container: #GUPnPDIDLLiteContainer
  *
  * Get the number of bytes used by all child items of the @container.
+ *
  * If storage used is unknown, -1 is returned.
  *
  * Return value: The number of bytes used by all children of the @container,
@@ -552,11 +540,11 @@ gupnp_didl_lite_container_get_storage_used (GUPnPDIDLLiteContainer *container)
         return g_ascii_strtoll (str, NULL, 10);
 }
 /**
- * gupnp_didl_lite_container_set_searchable:
+ * gupnp_didl_lite_container_set_searchable:(attributes org.gtk.Method.set_property=searchable):
  * @container: #GUPnPDIDLLiteContainer
- * @searchable: The searchibility
+ * @searchable: The search-ability
  *
- * (Un)set the searchibility of @container.
+ * (Un)set the search-ability of @container.
  **/
 void
 gupnp_didl_lite_container_set_searchable (GUPnPDIDLLiteContainer *container,
@@ -583,7 +571,7 @@ gupnp_didl_lite_container_set_searchable (GUPnPDIDLLiteContainer *container,
 }
 
 /**
- * gupnp_didl_lite_container_set_child_count:
+ * gupnp_didl_lite_container_set_child_count:(attributes org.gtk.Method.set_property=child-count):
  * @container: #GUPnPDIDLLiteContainer
  * @child_count: The child count
  *
@@ -612,7 +600,7 @@ gupnp_didl_lite_container_set_child_count (GUPnPDIDLLiteContainer *container,
 }
 
 /**
- * gupnp_didl_lite_container_set_container_update_id:
+ * gupnp_didl_lite_container_set_container_update_id:(attributes org.gtk.Method.set_property=container-update-id):
  * @container: #GUPnPDIDLLiteContainer
  * @update_id: The container update ID
  *
@@ -672,7 +660,7 @@ gupnp_didl_lite_container_unset_container_update_id
 }
 
 /**
- * gupnp_didl_lite_container_set_total_deleted_child_count:
+ * gupnp_didl_lite_container_set_total_deleted_child_count:(attributes org.gtk.Method.set_property=total-deleted-child-count):
  * @container: #GUPnPDIDLLiteContainer
  * @count: The container update ID
  *
@@ -737,6 +725,8 @@ gupnp_didl_lite_container_unset_total_deleted_child_count
  * @create_class: The createClass to add.
  *
  * Add a new create class to the @container. includeDerived defaults to "0".
+ * If setting the includeDerived is required, see
+ * [method@GUPnPAV.DIDLLiteContainer.add_create_class_full]
  **/
 void
 gupnp_didl_lite_container_add_create_class (
@@ -752,8 +742,8 @@ gupnp_didl_lite_container_add_create_class (
  * gupnp_didl_lite_container_add_create_class_full:
  * @container: #GUPnPDIDLLiteContainer
  * @create_class: The createClass to add.
- * @include_derived: Whether object with dervied classes may be created in
- * this container or not.
+ * @include_derived: Whether object with derived classes, such as
+ * object.item.imageItem.Photo for a create class of object.item.imageItem are allowed.
  *
  * Add a new create class to the @container.
  **/
@@ -795,6 +785,10 @@ gupnp_didl_lite_container_add_create_class_full (
  * @search_class: The searchClass to add.
  *
  * Add a new search class to the @container.
+ *
+ * `includDerived` will default to "1". See
+ * [method@GUPnPAV.DIDLLiteContainer.add_search_class_full] if
+ * you need to set the property to "0".
  **/
 void
 gupnp_didl_lite_container_add_search_class (
