@@ -6,26 +6,15 @@
  *                                <zeeshanak@gnome.org>
  *          Krzesimir Nowak <krnowak@openismus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_DIDL_LITE_OBJECT_PRIVATE_H__
-#define __GUPNP_DIDL_LITE_OBJECT_PRIVATE_H__
+#ifndef GUPNP_DIDL_LITE_OBJECT_PRIVATE_H
+#define GUPNP_DIDL_LITE_OBJECT_PRIVATE_H
 
 #include "xml-util.h"
+#include "gupnp-didl-lite-object.h"
 
 #include <glib-object.h>
 #include <libxml/tree.h>
