@@ -13,8 +13,9 @@
  */
 
 /**
- * SECTION:gupnp-didl-lite-resource
- * @short_description: DIDL-Lite Resource
+ * GUPnPDIDLLiteResource:
+ *
+ * DIDL-Lite Resource
  *
  * #GUPnPDIDLLiteResource respresent a DIDL-Lite resource (res) element.
  */
@@ -1932,7 +1933,7 @@ gupnp_didl_lite_resource_set_subtitle_file_type
         if (type == NULL)
                 xmlUnsetNsProp (priv->xml_node,
                                 priv->pv_ns,
-                                (unsigned char *) "subtitleFileUri");
+                                (unsigned char *) "subtitleFileType");
         else {
                 av_xml_util_get_ns (priv->xml_doc->doc,
                                     GUPNP_XML_NAMESPACE_PV,
