@@ -7,23 +7,14 @@
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  * Author: Krzesimir Nowak <krnowak@openismus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
+#include <config.h>
+
 #include <string.h>
+#include <glib/gprintf.h>
 
 #include "xml-util.h"
 
@@ -41,7 +32,7 @@ static GUPnPXMLNamespaceDescription gupnp_xml_namespaces[] =
         { "urn:schemas-dlna-org:metadata-1-0/", "dlna" },
         { "http://www.pv.com/pvns/", "pv" },
         { "urn:schemas-upnp-org:metadata-1-0/upnp/", "upnp" },
-        { NULL }
+        { NULL, NULL }
 };
 
 GUPnPAVXMLDoc *
@@ -51,34 +42,22 @@ av_xml_doc_new (xmlDoc *doc)
 
         g_return_val_if_fail (doc, NULL);
 
-        ret = g_new0 (GUPnPAVXMLDoc, 1);
-        ret->refcount = 1;
+        ret = g_rc_box_new0(GUPnPAVXMLDoc);
         ret->doc = doc;
 
         return ret;
 }
 
-GUPnPAVXMLDoc *
-av_xml_doc_ref (GUPnPAVXMLDoc *doc)
+static void
+av_xml_doc_free (GUPnPAVXMLDoc *doc)
 {
-        g_return_val_if_fail (doc, NULL);
-        g_return_val_if_fail (doc->refcount > 0, NULL);
-        g_atomic_int_inc (&doc->refcount);
-
-        return doc;
+        g_clear_pointer (&doc->doc, xmlFreeDoc);
 }
 
 void
 av_xml_doc_unref (GUPnPAVXMLDoc *doc)
 {
-        g_return_if_fail (doc);
-        g_return_if_fail (doc->refcount > 0);
-
-        if (g_atomic_int_dec_and_test (&doc->refcount)) {
-                xmlFreeDoc (doc->doc);
-                doc->doc = NULL;
-                g_free (doc);
-        }
+        g_rc_box_release_full (doc, (GFreeFunc) av_xml_doc_free);
 }
 
 xmlNode *
@@ -570,4 +549,47 @@ av_xml_util_get_ns (xmlDocPtr doc, GUPnPXMLNamespace ns, xmlNsPtr *ns_out)
         return tmp_ns;
 }
 
-G_DEFINE_BOXED_TYPE (GUPnPAVXMLDoc, av_xml_doc, av_xml_doc_ref, av_xml_doc_unref)
+void
+av_xml_util_set_int_prop (xmlNodePtr node, const char *name, int value)
+{
+        char *str;
+
+        str = g_strdup_printf ("%d", value);
+        xmlSetProp (node, (unsigned char *) name, (unsigned char *) str);
+        g_free (str);
+}
+
+void
+av_xml_util_set_prop (xmlNodePtr node,
+                      const char *name,
+                      const char *format,
+                      ...)
+{
+        va_list args;
+
+        va_start (args, format);
+        char *str = NULL;
+        g_vasprintf (&str, format, args);
+        xmlSetProp (node, (xmlChar *) name, (xmlChar *) str);
+        g_free (str);
+        va_end (args);
+}
+
+void
+av_xml_util_set_ns_prop (xmlNodePtr node,
+                         xmlNsPtr ns,
+                         const char *name,
+                         const char *format,
+                         ...)
+{
+        va_list args;
+
+        va_start (args, format);
+        char *str = NULL;
+        g_vasprintf(&str, format, args);
+        xmlSetNsProp (node, ns, (xmlChar *) name, (xmlChar *) str);
+        g_free (str);
+        va_end (args);
+}
+
+G_DEFINE_BOXED_TYPE (GUPnPAVXMLDoc, av_xml_doc, g_rc_box_acquire, av_xml_doc_unref)
